function [sys,E]=OscArm(L,Ep0,m,varargin)
% OscArm determina las energías de los estados ligados de un objeto físico   
%  confinado en un pozo armónico de energía potencial.
%  
%  [sys,E]=OscArm(L,Ep0,C,m,varargin) 
%					-- varargin indica varios argumentos de entrada
%   >> L    = Anchura del pozo (nm)
%   >> Ep0  = Profundidad del pozo (eV) (Ep0 < 0)
%   >> m    = Masa del objeto físico (respecto a la del electrón) 
%   >> varargin  	= Argumentos de entrada opcionales
%           > nx   	= Número de puntos en el eje Ox (defecto: 100)
%           > nE   	= Número de valores de energía (defecto: 500)
%           > Emin 	= Valor inferior de la energía (defecto: min(Ep))
%           > Emax 	= Valor superior de la energía (defecto: 0)
%
% Olivier Pujol (2010)

%% Argumentos opcionales de entrada

switch length(varargin)
    case 0
        nx=100;                     % Valor por defecto del número de puntos en Ox
        nE=500;                     % Valor por defecto del número de valores de la energía
    case 1
        nx=varargin{1};             % Valor por defecto del número de puntos en Ox
        nE=500;                     % Valor por defecto del número de valores de la energía
    case 2
        nx=varargin{1};             % Valor por defecto del número de puntos en Ox
        nE=varargin{2};             % Valor por defecto del número de valores de la energía
    case 4
        nx=varargin{1};            	% Valor del número de puntos en Ox 
        nE=varargin{2};             % Valor del número de valores de la energía
        E=linspace(varargin{3},varargin{4},nE);     % Vector de los valores de la energía
    otherwise
        ('¡Número de argumentos opcionales de entrada incorrecto!');
end

%% Energía potencial

% Construcción
x=linspace(-L/2,L/2,nx);     % Intervalo espacial
Epc=4*Ep0*(x/L).^2;          % Energía potencial parabólica (el origen es el mínimo)

% Digitalización
[M,xt,Ep]=digitalización(x,Epc);

% Valores de la energía
if (length(varargin)~=4)
    E=linspace(min(Ep),Ep0,nE);   % Vector de los valores de la energía
end    

if (max(E)>Ep0)
    disp(' ');
    disp('Algunos valores de la energía no están en el dominio de los estados ligados');
    disp(' ');
    return;
end

%% Estados ligados (o confinados)

[sys,E]=Epot(M,xt,Ep,m,E);          % Sistema 
sisconf(sys,E);                     % Estados ligados (o confinados)

return;