function k=VectOnda(E,m,Ep)
% VectOnda da el vector de onda complejo k de un objeto físico utilizando su 
%   energía, su masa, y los valores de la energía potencial. 
%
%   k=VectOnda(E,m,Ep)
%       >> E    = Energía del objeto físico (eV)
%       >> m    = Masa del objeto físico (respecto a la del electrón)
%       >> Ep   = Energías potenciales Ep(i) (eV), (i=1,2,...) 
%       << k    = Vectores de onda k(i) (nm^-1)
%                            
%   Olivier Pujol (2010)
%
%% Verificaciones

if (m<=0),error('¡La masa tiene que ser positiva!');end

%% Constantes y conversiones

% Constantes fundamentales 
h=6.6260755E-34;    %   Constante de Planck (J.s)
hbar=h/(2*pi);
hbar2=hbar^2;

me=0.91093897E-30;  %   Masa del electrón (kg)
eV=1.60217733E-19;  %   Electronvolt (J) 

% Conversiones
m=m*me;
E=E*eV;
nm=1E-9;

%% Cálculo de los vectores de onda

k=nan(size(Ep));
if (length(m)>1)
    for n=1:length(Ep)
        Ep(n)=Ep(n)*eV;
        if (Ep(n)<E), k(n)=sqrt( (2*m(n)/hbar2).*(E-Ep(n)) );end
        if (Ep(n)>E), k(n)=1i*sqrt( (2*m(n)/hbar2).*(Ep(n)-E) );end
        if (Ep(n)==E),error('¡Uno de los valores de E conduce al caso singular k=0!');end
    end
end
if (length(m)==1)
    for n=1:length(Ep)
        Ep(n)=Ep(n)*eV;
        if (Ep(n)<E), k(n)=sqrt( (2*m/hbar2)*(E-Ep(n)) );end
        if (Ep(n)>E), k(n)=1i*sqrt( (2*m/hbar2)*(Ep(n)-E) );end
        if (Ep(n)==E),error('¡Uno de los valores de E conduce al caso singular k=0!');end
    end
end

k=k*nm;

return;