function [R,T]=factRT(sys,TES)
% FactRT da las probabilidades de reflexión y de transmisión de un objeto 
%   físico que interactúa con un escalón de energía potencial.
%
%   [R,T]=FactRT(sys,TES)
%       >> sys  = Sistema
%       >> TES  = Matriz de transferencia del sistema
%       << R    = Probabilidad de reflexión
%       << T    = Probabilidad de transmisión
%
% Olivier Pujol (2010)

if (nargin<1), error('¡Número incorrecto de argumentos de entrada!');end
%

nE=size(TES,2); % Número de valores de la energía
R=nan(1,nE);
T=nan(1,nE);

for iE=1:nE
    if ( (isreal(sys{iE}{1}(3))==1)&&(isreal(sys{iE}{1}(4))==1) )
        R(iE)=(abs(-TES{iE}(2,1)/TES{iE}(2,2)))^2;
        T(iE)=(1/abs(TES{iE}(2,2)))^2;
    end
%
    if ( (isreal(sys{iE}{1}(3))==1)&&(isreal(sys{iE}{1}(4))==0) )
        R(iE)=1;
        T(iE)=0;
    end
%
end

return;