function graf(sys,x,rho)
%   GRAF ofrece una representación gráfica de la energía potencial y de la 
%   densidad lineal de probabilidad de un objeto físico que interactúa con 
%   la misma.
%
%   GRAF(sys,x,rho)
%       >> sys 	= Sistema
%       >> x 	= Coordenada en el eje Ox 
%       >> rho 	= Densidad lineal de probabilidad
%
%   Olivier Pujol (2010)
%
%% Verificaciones

if (nargin~=3);error('¡Número incorrecto de argumentos de entrada!');end
if (isa(sys,'cell')==0),error('¡El primer argumento tiene que ser de tipo ''cell''!');end

%% Gráfico

figure
subplot(2,1,1)
plotsys(sys,x);
subplot(2,1,2);
plot_rho(x,rho);
%
return;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function plotsys(sys,x)
%
if (nargin~=2),error('¡Número incorrecto de argumentos de entrada!');end
%
xmin=x{1}(1);
xmax=x{end}(end);

if ( xmin>sys{1}{1}(5) || xmax<sys{1}{1}(6) )
    error('El sistema está fuera del intervalo espacial!');
end
%
%   Se necesita la posición y el valor de las energías potenciales para el primer valor de la energía (sys{1}). 
%   Es lo mismo para los otros valores de la energía. 

pos=nan(1,length(sys{1})-1);    % Inicialización
Ep=nan(1,length(sys{1})-1);     % Inicialización
%
for i=2:length(sys{1})
    if (isa(sys{1}{i},'escalón')==0),error('¡Tipo de argumento incorrecto!');end
    pos(i-1)=get(sys{1}{i},'Posición');
    Ep(i-1)=get(sys{1}{i},'EnergíaPotencialSalida');
end
%
pos=[xmin pos xmax];
Ep_e=sys{1}{1}(1);
Ep_s=sys{1}{1}(2);
Ep=[Ep_e Ep Ep_s];
%
hs=stairs(pos,Ep);
set(hs,'LineWidth',2,'Color','b');
axis([xmin xmax min(Ep)-0.2*max(Ep) max(Ep)+0.2*max(Ep)]);
grid on;
box on
xlabel('{\itx} (nm)');
title('{Energía potencial (eV)}');
%
return;
%
function plot_rho(x,rho)
%
if (nargin~=2),error('¡Número incorrecto de argumentos de entrada!');end
%
for i=1:length(x)
    plot(x{i},rho{i},'LineWidth',2,'Color','r');
    hold on;
end
axis tight;
grid on;
box on;
xlabel('{\itx} (nm)');
title('{|\it{\psi}|^{2}}');
%
return;
