function graf3D(M,xt,Ep,m,E,para)
% graf3D ofrece una representación gráfica de la probabilidad de transmisión T
%  en función de la energíe E y de otro parámetro elegido por el usuario. 
%
%   graf3D(M,xt,Ep,m,E,para)
%       >> M 	= Nombres de los escalones
%       >> xt 	= Posiciones de los escalones 
%       >> Ep 	= Valores de la energía potencial 
%       >> m 	= Masa del objeto físico (respecto a la del electrón) 
%       >> E 	= Valores de la energía del objeto físico
%       >> para = Valores del parámetro elegido por el  usuario
%
% Olivier Pujol (2010)
%

iconf=input('Estado ligado: no (escriba 0) / sí (escriba 1) ?');
im=input('¿Cuál es el número (índice) del escalón considerado? ');
type=input('Parámetro escogido para el escalón: anchura (escriba 1) / altura (escriba 2) :');

% Se pregunta si el escalón siguiendo el escalón considerado (im) tiene que ser trasladado?
if type==1 && size(xt,2)>2
    traslado=input('Translación del escalón que sigue el escalón considerado: no (escriba 0) / sí (escriba 1) :');
end
if (size(xt,2)<3),traslado=0;end     % Caso de una barrera o de un pozo

% Verificación
if (im > length(xt)) || (im < 1) 
    disp(' ');
    disp(['¡El número del escalón', num2str(im),'no existe!']);
    disp(['¡Se debe tener 1 <= im <= ', num2str(length(xt)),'! ']);
    disp(' ');
    return;
end

% Para cada valor del parámetro, se calcula primero el sistema, luego la  
% matriz de transferencia y finalmente las probabilidades R y T. 

R=nan(length(E),length(para));      % Inicialización
if (iconf==0)
    T=nan(length(E),length(para));  % Inicialización de T (estados de difusión)
else
    d=nan(length(E),length(para));  % Inicialización de d (estados ligados, o confinados)
end

switch type
    case 1    % El parámetro considerado es la posición del escalón
        
        if (para(1)<=xt(im-1))
            error('¡El valor mínimo del parámetro es más pequeño que la posición anterior del escalón!');
        end

        xt=repmat(xt,length(para),1);   % Replicación del vector xt (una dimensión). 

        switch traslado
            case 0      % Las matrices sucesivas no son trasladadas
                if (para(end)>=xt(im+1) && size(xt,2)>=3)
                    error('¡El valor máximo del parámetro es más grande que la posición del escalón que sigue!');
                end
                xt(:,im)=para'; % Nuevo vector xt
                
            case 1      % Las matrices sucesivas son trasladadas
                delta=para'-xt(1,im);
                for i=im:size(xt,2)
                    xt(:,i)=xt(:,i)+delta;  % Nuevo vector xt
                end                
        end
                
        for ipara=1:length(para)
            [sys]=Epot(M,xt(ipara,:),Ep,m,E);
            TES=matriz(sys);
            switch iconf
                case 0
                [R(1:length(sys),ipara),T(1:length(sys),ipara)]=factRT(sys,TES);
                case 1
                d(1:length(sys),ipara)=Calc_d(TES);
            end
        end
        
    case 2    % El parámetro considerado es la altura del escalón  
              % (Atención: Escalón número 1 --> Altura del escalón número 2
        
        Ep=repmat(Ep,length(para),1);
        Ep(:,im+1)=para';
        
        for ipara=1:length(para)
            [sys,E]=Epot(M,xt,Ep(ipara,:),m,E);
            TES=matriz(sys);
            switch iconf
                case 0
                [R(1:length(sys),ipara),T(1:length(sys),ipara)]=factRT(sys,TES);
                case 1
                d(1:length(sys),ipara)=Calc_d(TES);
            end
        end       
end

clear TES sys

% Gráfico

figure
if (iconf==0),surf(para,E,T);end            % El modo de gráfico puede ser surf o mesh, etc. (Véase la documentación de Matlab)
if (iconf==1),surf(para,E,log(abs(d)));end  % Idem
shading interp;
colormap('jet');
colorbar('vertical');
if (type==1);xlabel(['Posición del escalón',num2str(im),' (nm) ']);end
if (type==2);xlabel(['Altura del escalón',num2str(im),' (eV) ']);end
ylabel('Energía  (eV)');
if (iconf==0),title('Probabilidad de transmisión');end
if (iconf==1),title('Valor absoluto del logaritmo de elemento d (matriz abcd)');end
axis tight

return;

function d=Calc_d(TES)

d=nan(1,length(TES));   % Inicialización

for i=1:size(TES,2)
    d(i)=TES{i}(2,2);   % Elemento d
end

return;