function grafE(sys,E,param)
% grafE representa gráficamente la energía potencial considerada y un parámetro  
%  (el más interesante es la probabilidad de transmisión T) en función de los 
%   valores de la energía.  
%
%   grafE(sys,E,param)
%       >>  sys 	= Sistema
%       >>  E 		= Valores de la energía del objeto físico 
%       >>  param	= Parámetro considerado
%
% Olivier Pujol (2010)
%
%%
if (nargin~=3);error('¡Número incorrecto de argumentos de entrada!');end
if (isa(sys,'cell')==0),error('¡El primer argumento debe ser de tipo ''cell''!');end
%
L=get(sys{1}{length(sys{1})},'Posición')-get(sys{1}{2},'Posición');
xmin=get(sys{1}{2},'Posición')-0.5*L;
xmax=get(sys{1}{length(sys{1})},'Posición')+0.5*L;
clear L
%
pos=nan(1,length(sys{1})-1);    % Inicialización
Ep=nan(1,length(sys{1})-1);     % Inicialización
%
for i=2:length(sys{1})
    if (isa(sys{1}{i},'escalón')==0),error('¡Tipo de argumento incorrecto!');end
    pos(i-1)=get(sys{1}{i},'Posición');
    Ep(i-1)=get(sys{1}{i},'EnergíaPotencialSalida');
end
%
pos=[xmin pos xmax];
Ep_e=sys{1}{1}(1);
Ep_s=sys{1}{1}(2);
Ep=[Ep_e Ep Ep_s];
%
figure;
subplot(1,2,1)
hs=stairs(pos,Ep);
set(hs,'LineWidth',2,'Color','b');
axis([xmin xmax min(Ep) max(E)]);
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
xlabel('{\itx} (nm)');
title('{Energía potencial (eV)}');

subplot(1,2,2);
plot(param,E);
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
axis tight
labelx=input('Notación del parámetro representado gráficamente vs. E: ');
xlabel(labelx);
ylabel('{\itE} (eV)');
%
return;