function sisper(sys,E,period)
% SISPER determina las bandas de energa permitidas (de conduccin) y prohibidas (de valencia) 
%  de un objeto fsico que interacta con una energa potencial peridica. 
%  Tambin se ofrece una representacin grfica de esta periodicidad y de esas bandas.
%
%	SISPER(sys,E,period)
%		>> sys 		= Sistema
%		>> E		= Energa del objeto fsico
%		>> period	= Periodicidad espacial de la energa potencial
%
%	Olivier Pujol (2010)
%

if (nargin~=3);error('Nmero de argumentos de entrada incorrecto!');end
if (isa(sys,'cell')==0),error('El primer argumento tiene que ser de tipo ''cell''!');end
if (period<=0);error('La periodicidad tiene que ser positiva!');end
%
%% Clculo de la matriz de transferencia abcd del patrn que se repite peridicamente

TES=matriz(sys);

%% Extraccin de la parte real del elemento a 

L=get(sys{1}{length(sys{1})},'Posicin')-get(sys{1}{2},'Posicin');     % Anchura del sistema

if (period-L<=0),error('[La periodicidad es demasiado pequea: tiene que superar la anchura del sistema!]');end

ke=get(sys{1}{2},'VectorOndaEntrada');      % Vector de onda de entrada
Re_a=nan(1,length(TES)); % Inicializacin

for n=1:size(TES,2)
    Re_a(n)=abs(real(TES{n}(1,1)*exp(1i*ke*(period-L))));    % Parte real de a
end

clear TES

%% Grfico

%  Representacin del patrn

xmin=get(sys{1}{2},'Posicin');                         	% El patrn empieza con el primer escaln
xmax=get(sys{1}{length(sys{1})},'Posicin')+(period-L);    	% El patrn contiene adems la regin de salida (Ep=cte) de longitud period-L

pos=nan(1,length(sys{1})-1);    % Inicializacin
Ep=nan(1,length(sys{1})-1);     % Inicializacin
%
for i=2:length(sys{1})
    if (isa(sys{1}{i},'escaln')==0),error('Tipo de argumento incorrecto!');end
    pos(i-1)=get(sys{1}{i},'Posicin');
    Ep(i-1)=get(sys{1}{i},'EnergaPotencialSalida');
end
%
pos=[xmin pos xmax];
Ep_e=sys{1}{1}(1);
Ep_s=sys{1}{1}(2);
Ep=[Ep_e Ep Ep_s];

figure
subplot(1,2,1)
hs=stairs(pos,Ep);
set(hs,'LineWidth',2,'Color','b');
axis([xmin-L xmax min(Ep) max(E)]);
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
xlabel('{\itx} (nm)');
title('{Energa potencial (eV) del patrn}');

%  Representacin de las bandas de energas permitidas (o de conduccin)

subplot(1,2,2);
plot(Re_a,E);
line([1 1],[0 max(E)],'LineWidth',2,'Color','r','LineStyle','--')
axis([0 1.1 min(E) max(E)])
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
xlabel('| Re(a) |');
ylabel('Energa (eV)');
title('Bandas de energas permitidas (o de conduccin)');
return;
